package com.siwei.rsmonitoring.service;

import java.util.List;
import com.siwei.rsmonitoring.domain.TZdkjbxx;

/**
 * 地块基本信息（DKJBXX）Service接口
 * 
 * @author siwei
 * @date 2025-01-20
 */
public interface ITZdkjbxxService 
{
    /**
     * 查询地块基本信息（DKJBXX）
     * 
     * @param id 地块基本信息（DKJBXX）主键
     * @return 地块基本信息（DKJBXX）
     */
    public TZdkjbxx selectTZdkjbxxById(String id);

    /**
     * 查询地块基本信息（DKJBXX）列表
     * 
     * @param tZdkjbxx 地块基本信息（DKJBXX）
     * @return 地块基本信息（DKJBXX）集合
     */
    public List<TZdkjbxx> selectTZdkjbxxList(TZdkjbxx tZdkjbxx);

    /**
     * 新增地块基本信息（DKJBXX）
     * 
     * @param tZdkjbxx 地块基本信息（DKJBXX）
     * @return 结果
     */
    public int insertTZdkjbxx(TZdkjbxx tZdkjbxx);

    /**
     * 修改地块基本信息（DKJBXX）
     * 
     * @param tZdkjbxx 地块基本信息（DKJBXX）
     * @return 结果
     */
    public int updateTZdkjbxx(TZdkjbxx tZdkjbxx);

    /**
     * 批量删除地块基本信息（DKJBXX）
     * 
     * @param ids 需要删除的地块基本信息（DKJBXX）主键集合
     * @return 结果
     */
    public int deleteTZdkjbxxByIds(String[] ids);

    /**
     * 删除地块基本信息（DKJBXX）信息
     * 
     * @param id 地块基本信息（DKJBXX）主键
     * @return 结果
     */
    public int deleteTZdkjbxxById(String id);
}
